@@ -1,6 +1,5 @@
 """
-Lump 11 - Face Ids
-==================
+.. Lump 11 - Face Ids
 
 This lump contains an array of :any:`dfaceid_t`. This array matches the array of dface_t (:ref:`see lump_7<lump_7>`).
 """
@@ -16,7 +15,7 @@ from construct import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 dfaceid_t = Struct(
-    'hammerFaceID' / Int16ul * "index into :ref:`lump 27<lump_27>`",
+    'hammerFaceID' / Int16ul * "The original face id",
 )
 
 
