@@ -1,6 +1,5 @@
 """
-Lump 13 - Surfedges
-===================
+.. Lump 13 - Surfedges
 
 This lump contains an array of :any:`Int<int>`. The absolute value references the edge array (:ref:`lump_12<lump_12>`). Positive values indicate the edge is defined from the first to second vertex. Negative values indicate the edge is defined from second to first vertex.
 """
